==> Ver%203.0.0.zip: Ver 3.0.0/src/jp/mosp/common/action/MosPIndexAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2008 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.action;

import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;
import jp.mosp.common.dto.CmAspUserDto;
import jp.mosp.common.vo.MosPLoginVo;

public class MosPIndexAction extends MosPAction {

	/**
	 * RXgN^
	 */
	public MosPIndexAction() {
		super();
		// ʏݒ
		setNeedSession(false);
		setNeedAspUser(false);
		setNeedUser(false);
		setCheckProcSeq(false);
		setCheckAuth(false);
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// X|X^Cv
		request.setAttribute(MospConst.ATT_RESPONASE_TYPE, MospConst.RESPONSE_TYPE_HTML);
		// ZbV̎擾
		session = request.getSession(true);
		// y[W̎擾
		getIndexUrl();
		// ZbVɏZbg
		session.setAttribute(MospConst.ATT_ASPUSER, aspUser);
	}

	/**
	 * Jڐ擾
	 * @throws Exception
	 */
	protected void getIndexUrl() throws Exception {
		// ݒt@CASPݒɂď𕪊
		aspUser = new CmAspUserDto();
		// St@C̐ݒ
		setUseLogo();
		switch (MospUtility.getAspFlag(cfg)) {
		case 0:
			// 0FASP(x[U[:1Av)
			// ASP̃ANVNXɏϏ邢͂̂܂JSP֔΂Ă܂B
			//MospUtility.getActionInstance(ctl, "test");
			//break;
		case 1:
			// 1FASP(1[U[:1Av)
			// ASPOCy[W֑J
			break;
		case 2:
			// 2FASP
			initNonAspUser();
			break;
		default:
			throw new MospException(MospConst.EX_ASP_PROPERTIES);
		}
	}

	protected MosPLoginVo getInitVo() {
		return new MosPLoginVo();
	}

	/**
	 * ASP
	 */
	protected void initNonAspUser() {
		// ASP[U[Zbg
		createAspUser();
		MosPLoginVo vo = getInitVo();
		vo.initVo(cfg, msg, cmd, aspUser, null);
		vo.setUserId("");
		vo.setPass("");
		// VOyёJڐZbg
		setVo(vo);
		setUrl(vo.getRetUrl());
	}

}

==> Ver%203.1.1.zip: Ver 3.1.1/src/jp/mosp/common/action/MosPIndexAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.action;

import jp.mosp.common.MosPAction;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;
import jp.mosp.common.vo.MosPLoginVo;

public class MosPIndexAction extends MosPAction {

	/**
	 * RXgN^
	 */
	public MosPIndexAction() {
		super();
		// ʏݒ
		setNeedSession (false);
		setNeedAspUser (false);
		setNeedUser    (false);
		setCheckProcSeq(false);
		setCheckAuth   (false);
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// ZbV̎擾
		session = request.getSession(true);
		// y[W̎擾
		getIndexUrl();
		// ZbVɏZbg
		session.setAttribute(MospConst.ATT_ASPUSER, aspUser);
	}

	/**
	 * Jڐ擾
	 * @throws Exception
	 */
	protected void getIndexUrl() throws Exception {
		// ݒt@CASPݒɂď𕪊
		createAspUser();
		// St@C̐ݒ
		setUseLogo();
		switch (MospUtility.getAspFlag(cfg)) {
		case 0:
			// 0FASP(x[U[:1Av)
			// ASP̃ANVNXɏϏ邢͂̂܂JSP֔΂Ă܂B
			//break;
		case 1:
			// 1FASP(1[U[:1Av)
			// ASPOCy[W֑J
			break;
		case 2:
			// 2FASP
			initNonAspUser();
			break;
		default:
			throw new MospException(MospConst.EX_ASP_PROPERTIES);
		}
	}

	/**
	 * ASP
	 */
	protected void initNonAspUser() {
		MosPLoginVo vo = new MosPLoginVo(cfg, msg, nam, cmd, aspUser, user);
		vo.setUserId("");
		vo.setPass("");
		// VOyёJڐZbg
		setVo(vo);
		setUrl(vo.getRetUrl());
	}

}
